#
# spec file for package python-ndg-httpsclient
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-ndg-httpsclient
Version:        0.5.1
Release:        3.22
Summary:        HTTPS support for httplib and urllib2 using PyOpenSSL
License:        BSD-2-Clause
Group:          Development/Languages/Python
URL:            https://github.com/cedadev/ndg_httpsclient/
Source:         https://files.pythonhosted.org/packages/source/n/ndg_httpsclient/ndg_httpsclient-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-pyOpenSSL
Requires:       python-pyasn1 >= 0.1.1
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%python_subpackages

%description
This is a HTTPS client implementation for httplib and urllib2 based on
PyOpenSSL.  PyOpenSSL provides a more fully featured SSL implementation over the
default provided with Python and importantly enables full verification of the
SSL peer.

%prep
%setup -q -n ndg_httpsclient-%{version}

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/ndg_httpclient
%python_expand %fdupes %{buildroot}%{$python_sitelib}

# tests require internet connection

%post
%python_install_alternative ndg_httpclient

%postun
%python_uninstall_alternative ndg_httpclient

%files %{python_files}
%doc README.md
%license ndg/httpsclient/LICENSE
%{python_sitelib}/*
%python_alternative %{_bindir}/ndg_httpclient

%changelog
* Thu May 21 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Sun Jun  2 2019 Jan Engelhardt <jengelh@inai.de>
- Use noun phrase in summary.
* Wed May 29 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.5.1
  0.5.*
  * Drop support for EOL Python 2.6 and 3.3
  * Updated SSL Context objects to default to TLS 1.2
  * Fix to Subject Alternative Name handling to allow for
    certificates with more than 64 names (max now 1024).
  0.4.*
  * Fix to ndg namespace package warning issue
  * Minor fix for installation: set minimum release for pyasn1
  * Fix to bug in ndg.httpsclient.utils.open_url - duplicate open call.
  * Moved LICENSE file into package
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Thu Aug 24 2017 jmatejek@suse.com
- singlespec auto-conversion
* Fri Jun 12 2015 t.gruner@katodev.de
- Initial Version 0.4.0
  * Made dual compatible with Python 2 / 3.
  0.3.3
-----
  * Fix to add in AnotherName for ``subjectAltNames`` field - added for support for CACert issued
  certs (thanks to Gu1).
  * Fix to HTTP Basic Auth option for ``ndg.httpsclient.utils.main``
  * Fix to ``ServerSSLCertVerification`` so that it can pass a function-based callback instead of using ``__call__``. In newer versions of OpenSSL (>= 0.14) the latter failed because of a request for ``__name__`` attribute.
  0.3.2
-----
  * Fix to SubjectAltNames support check - should only be enabled if pyasn1 is
  installed.
  * Fix to open_url: HTTP Request object was being created inside if headers is
  None block - now corrected to create regardless.
  * Added http basic auth support to script. (Thanks to Willem van Engen)
  0.3.1
-----
  * extended utils functions to support keyword for passing additional urllib2
  handlers.
  0.3.0
-----
  * Added ndg.httpsclient.utils.fetch_stream_from_url function and added
  parameter for data to post in open_url and fetch_* methods.
  * fix to ndg.httpsclient.utils module _should_use_proxy and open_url functions
  0.2.0
-----
  * added support for SSL verification with subjectAltNames using pyasn1
  * fixed minor bug - SSL cert DN prefix matching
  0.1.0
-----
  Initial release
